@@ -1,6 +1,17 @@
 WHATS_NEW = """
 # 更新日志
 ## kaa
+### v2025.8.23.0
+脚本：
+* [新增] 新增闲置挂机功能（#54e2101）
+* [修复] 再次修复商店刷新后第二次购买会跳过第一行的问题（#b72cdf4）
+* [修复] 修复游戏更新导致的培育时识别编成编号失败（#24d14d4）
+* [修复] 修复培育内周数识别失败的问题（#3a84994）
+* [修复] 培育商店中有时候会因为结束按钮被挡住而卡住（#e93cfa8）
+
+其他：
+* [文档] 更新 README（#841fcf2）
+
 ### v2025.8.17.0
 脚本：
 * [修复] 尝试修复进入每日商店时报错的问题（#e9529b7）
