@@ -6,51 +6,51 @@ from kotonebot.backend.core import Image, HintBox, HintPoint
 
 class Common:
     
-    ButtonClose = Image(path=sprite_path(r"7b8541a8-9e82-410b-b053-3ebc96b36604.png"), name="button_close.png")
+    ButtonClose = Image(path=sprite_path(r"b241eff8-039e-4734-bea2-e10da89426d8.png"), name="button_close.png")
 
-    ButtonCompletion = Image(path=sprite_path(r"a898c01d-1347-484f-b2b0-10858a1ef3a6.png"), name="button_completion.png")
+    ButtonCompletion = Image(path=sprite_path(r"f53ff71d-54b5-44d2-9e48-ad2dee918fd1.png"), name="button_completion.png")
 
-    ButtonConfirm = Image(path=sprite_path(r"0e332904-cace-4d02-9575-100a359c548f.png"), name="button_confirm.png")
+    ButtonConfirm = Image(path=sprite_path(r"fc64316e-8394-4019-a16f-d6e7bb83d9bf.png"), name="button_confirm.png")
 
-    ButtonConfirmNoIcon = Image(path=sprite_path(r"5cd3481b-2388-4461-b525-c2f78050822f.png"), name="button_confirm_no_icon.png")
+    ButtonConfirmNoIcon = Image(path=sprite_path(r"c84958c3-37a8-4f1e-9874-45d2c3723b80.png"), name="button_confirm_no_icon.png")
 
-    ButtonContest = Image(path=sprite_path(r"b5a883c1-8086-4c60-a789-a7819c674645.png"), name="button_contest.png")
+    ButtonContest = Image(path=sprite_path(r"46abcf20-513c-4759-9976-eaab68be7f8f.png"), name="button_contest.png")
 
-    ButtonEnd = Image(path=sprite_path(r"ccbbecec-5cf5-4f9f-8358-6b3408689234.png"), name="button_end.png")
+    ButtonEnd = Image(path=sprite_path(r"b34a76e2-e318-47a0-b194-6e1b01eb269c.png"), name="button_end.png")
 
-    ButtonHome = Image(path=sprite_path(r"06df0c16-bb7e-41b7-90fe-afc14379b90f.png"), name="button_home.png")
+    ButtonHome = Image(path=sprite_path(r"cf89988c-c930-4890-8a55-018de7a4ae5a.png"), name="button_home.png")
 
-    ButtonIconArrowShort = Image(path=sprite_path(r"25ceaa36-a432-4bf3-80b7-11c94cd82357.png"), name="button_icon_arrow_short.png")
+    ButtonIconArrowShort = Image(path=sprite_path(r"e734df59-a24f-42e2-9f53-3ca720ddc612.png"), name="button_icon_arrow_short.png")
 
-    ButtonIconArrowShortDisabled = Image(path=sprite_path(r"bfa4b6bf-c032-46b8-9ce3-268717e4e364.png"), name="button_icon_arrow_short_disabled.png")
+    ButtonIconArrowShortDisabled = Image(path=sprite_path(r"184e517f-f37f-4cc8-ac49-6858025903ee.png"), name="button_icon_arrow_short_disabled.png")
 
-    ButtonIconCheckMark = Image(path=sprite_path(r"8bad2dbc-9f3a-443f-a3ff-048e70577a97.png"), name="button_icon_check_mark.png")
+    ButtonIconCheckMark = Image(path=sprite_path(r"ceaa1281-57d5-4c32-b5e2-86781518709b.png"), name="button_icon_check_mark.png")
 
-    ButtonIconClose = Image(path=sprite_path(r"2fc0a912-8d9b-48a3-b942-a25274c83edd.png"), name="button_icon_close.png")
+    ButtonIconClose = Image(path=sprite_path(r"8836e28c-e310-4870-94d2-b58e5dffad49.png"), name="button_icon_close.png")
 
-    ButtonIdol = Image(path=sprite_path(r"04622143-7f9e-47a8-86a5-be2b81d13cb6.png"), name="button_idol.png")
+    ButtonIdol = Image(path=sprite_path(r"fba7b4b2-46d3-4a5a-a161-6891014e6daf.png"), name="button_idol.png")
 
-    ButtonIdolSupportCard = Image(path=sprite_path(r"8bdcc43b-876d-451f-b300-67c16c6f5c9f.png"), name="button_idol_support_card.png")
+    ButtonIdolSupportCard = Image(path=sprite_path(r"9dcb4207-f546-4382-a87d-5d3377a31f4f.png"), name="button_idol_support_card.png")
 
-    ButtonNext = Image(path=sprite_path(r"7533e4fd-e411-4386-a0fb-aa8f2cbeb216.png"), name="button_next.png")
+    ButtonNext = Image(path=sprite_path(r"cca278bb-88cb-4898-8bbe-f52a49a0f740.png"), name="button_next.png")
 
-    ButtonNextNoIcon = Image(path=sprite_path(r"bc393fa9-317c-48f9-88cf-cd4d93af1569.png"), name="button_next_no_icon.png")
+    ButtonNextNoIcon = Image(path=sprite_path(r"5efaf4bf-b3cb-456f-88a1-ff1d28be80c1.png"), name="button_next_no_icon.png")
 
-    ButtonRetry = Image(path=sprite_path(r"5528a0a0-2f1e-41f8-b55f-a565a2f80908.png"), name="button_retry.png")
+    ButtonRetry = Image(path=sprite_path(r"724e9b7b-0bf6-4d78-b887-9b108474e732.png"), name="button_retry.png")
 
-    ButtonSelect = Image(path=sprite_path(r"651b2464-0c4a-4f3d-9452-5a40897b39e1.png"), name="button_select.png")
+    ButtonSelect = Image(path=sprite_path(r"81b9a59e-5714-459b-b6ce-03e1f4c4e503.png"), name="button_select.png")
 
-    ButtonStart = Image(path=sprite_path(r"288a0541-a175-47b4-b75c-2e845e27cba6.png"), name="button_start.png")
+    ButtonStart = Image(path=sprite_path(r"8f8f1144-5c30-41f0-8a6b-b39fe78e3e99.png"), name="button_start.png")
 
-    ButtonToolbarHome = Image(path=sprite_path(r"a18a08f5-c752-4fa4-a451-b48f5ca11360.png"), name="button_toolbar_home.png")
+    ButtonToolbarHome = Image(path=sprite_path(r"87f96abd-8290-4a06-bfc4-c7275cd01d9a.png"), name="button_toolbar_home.png")
 
-    ButtonToolbarMenu = Image(path=sprite_path(r"db86f5a5-0272-4a74-893e-077acbbecf23.png"), name="button_toolbar_menu.png")
+    ButtonToolbarMenu = Image(path=sprite_path(r"d55c4fd9-f8be-467a-923f-03cef8bd0525.png"), name="button_toolbar_menu.png")
 
-    CheckboxUnchecked = Image(path=sprite_path(r"f47d8096-63bf-42ed-8f4f-5f6f1d8772f4.png"), name="checkbox_unchecked.png")
+    CheckboxUnchecked = Image(path=sprite_path(r"32966af9-8bfe-4b67-b9b5-2fd5e2678468.png"), name="checkbox_unchecked.png")
 
-    TextGameUpdate = Image(path=sprite_path(r"65dbaa8c-2053-4441-9c31-8fd8fc8c87d8.png"), name="text_game_update.png")
+    TextGameUpdate = Image(path=sprite_path(r"f4212619-497f-4dcd-a197-e7c4c1c1a8ad.png"), name="text_game_update.png")
 
-    TextNetworkError = Image(path=sprite_path(r"c1504a57-77f0-46ca-a30b-162120489d5c.png"), name="text_network_error.png")
+    TextNetworkError = Image(path=sprite_path(r"80bfcb8e-fb27-4240-85c5-61650419a304.png"), name="text_network_error.png")
 
     TextFastforwardCommuDialogTitle = Image(path=sprite_path(r"50e23c8a-7ba2-4c9c-9cfb-196c260fa1d5.png"), name="早送り確認")
 
@@ -72,55 +72,55 @@ class Common:
     pass
 class Daily:
     
-    ButonLinkData = Image(path=sprite_path(r"dfe926f6-a3b3-48c2-9ebd-757f77d932a6.png"), name="buton_link_data.png")
+    ButonLinkData = Image(path=sprite_path(r"5df708a6-1383-47a4-aec7-69f492f4f783.png"), name="buton_link_data.png")
 
-    ButtonAssignmentPartial = Image(path=sprite_path(r"0bd59a8f-6fbd-4c92-8c1e-1d58716b6d84.png"), name="button_assignment_partial.png")
+    ButtonAssignmentPartial = Image(path=sprite_path(r"6e314b73-5ff5-4aa9-9dc3-1ebf28a578a7.png"), name="button_assignment_partial.png")
 
-    ButtonClaimAllNoIcon = Image(path=sprite_path(r"a1bae28b-7b90-4009-b384-79f7a8974078.png"), name="button_claim_all_no_icon.png")
+    ButtonClaimAllNoIcon = Image(path=sprite_path(r"5661e7a0-9513-4bb6-9549-87b7ad871a0d.png"), name="button_claim_all_no_icon.png")
 
-    ButtonClubCollectReward = Image(path=sprite_path(r"9b0f6620-5fd0-4393-ae67-555baf171550.png"), name="button_club_collect_reward.png")
+    ButtonClubCollectReward = Image(path=sprite_path(r"ef601e20-dc47-4c70-a251-4238fde74d49.png"), name="button_club_collect_reward.png")
 
-    ButtonClubSendGift = Image(path=sprite_path(r"57cee3e6-eee4-4023-85f3-52959fa372a0.png"), name="button_club_send_gift.png")
+    ButtonClubSendGift = Image(path=sprite_path(r"53eca690-1c14-4424-9456-3a8397ae9ff3.png"), name="button_club_send_gift.png")
 
-    ButtonClubSendGiftNext = Image(path=sprite_path(r"9f41a6b4-2955-4105-8610-423f267807de.png"), name="button_club_send_gift_next.png")
+    ButtonClubSendGiftNext = Image(path=sprite_path(r"4999097e-2f8b-4965-9e7e-cb9801f8ed0e.png"), name="button_club_send_gift_next.png")
 
-    ButtonContestChallenge = Image(path=sprite_path(r"8c9c9195-4eed-407c-b1ab-bb616c7b2acc.png"), name="button_contest_challenge.png")
+    ButtonContestChallenge = Image(path=sprite_path(r"7f459ed4-063c-48ab-a9ed-48f73bd3a865.png"), name="button_contest_challenge.png")
 
-    ButtonContestChallengeStart = Image(path=sprite_path(r"ecc2500b-4916-4c47-a840-98233d53522b.png"), name="button_contest_challenge_start.png")
+    ButtonContestChallengeStart = Image(path=sprite_path(r"0bab5a6b-631c-4661-8035-50a03299bd08.png"), name="button_contest_challenge_start.png")
 
-    ButtonContestRanking = Image(path=sprite_path(r"78e27204-2544-419d-b66e-e9e7244f4460.png"), name="button_contest_ranking.png")
+    ButtonContestRanking = Image(path=sprite_path(r"b80cec57-1d9c-4e40-a4d2-df1e1b1546d3.png"), name="button_contest_ranking.png")
 
-    ButtonContestStart = Image(path=sprite_path(r"6d58dbfa-84e2-4a84-8c7c-133e459e9b40.png"), name="button_contest_start.png")
+    ButtonContestStart = Image(path=sprite_path(r"9a9c9044-53c6-40f7-8eb5-2dc71383e58c.png"), name="button_contest_start.png")
 
-    ButtonDailyShop = Image(path=sprite_path(r"1a06449d-472e-4c06-9dc1-1cb06b1b1ce5.png"), name="button_daily_shop.png")
+    ButtonDailyShop = Image(path=sprite_path(r"395a07be-38b7-4c8c-948e-9efcb93a2e49.png"), name="button_daily_shop.png")
 
-    ButtonHomeCurrent = Image(path=sprite_path(r"1e17f7b1-4f64-474c-aade-4b3de32c0de4.png"), name="button_home_current.png")
+    ButtonHomeCurrent = Image(path=sprite_path(r"2f707d1b-98d5-47b1-a14c-5c7b95a1cc8c.png"), name="button_home_current.png")
 
-    ButtonIconPass = Image(path=sprite_path(r"5fb7c821-63b4-4ee2-b6ea-16eec3a77251.png"), name="button_icon_pass.png")
+    ButtonIconPass = Image(path=sprite_path(r"a8a3d531-9024-4603-a864-64bfe439a9ab.png"), name="button_icon_pass.png")
 
-    ButtonIconSkip = Image(path=sprite_path(r"2fa084f5-0637-4d53-ada8-9c542d597a51.png"), name="button_icon_skip.png")
+    ButtonIconSkip = Image(path=sprite_path(r"34fd0d97-1018-4986-b990-29e48abc2a56.png"), name="button_icon_skip.png")
 
-    ButtonMission = Image(path=sprite_path(r"cf615078-aedf-46af-a94d-9328a16fbc13.png"), name="button_mission.png")
+    ButtonMission = Image(path=sprite_path(r"a7f4d9cb-d0ee-4abd-b9fa-148c059c7a0f.png"), name="button_mission.png")
 
-    ButtonPass = Image(path=sprite_path(r"40fc17b0-718c-432d-b784-92a22c2f7512.png"), name="button_pass.png")
+    ButtonPass = Image(path=sprite_path(r"e072322f-eff1-4cbd-80c2-4e2103a1aa2f.png"), name="button_pass.png")
 
-    ButtonPassClaim = Image(path=sprite_path(r"9d9dd078-9bb3-4f5f-9ef5-63c203bf02c9.png"), name="button_pass_claim.png")
+    ButtonPassClaim = Image(path=sprite_path(r"647e6110-8c89-4c34-9352-b8b321c61500.png"), name="button_pass_claim.png")
 
-    ButtonPresentsPartial = Image(path=sprite_path(r"ca680286-0937-46e1-8b4d-ee900baed756.png"), name="button_presents_partial.png")
+    ButtonPresentsPartial = Image(path=sprite_path(r"d88c35b8-f101-4557-b2a5-0f7846fecd4c.png"), name="button_presents_partial.png")
 
-    ButtonProduce = Image(path=sprite_path(r"ad455e8e-fb2f-4180-af29-7ef66c98daa9.png"), name="button_produce.png")
+    ButtonProduce = Image(path=sprite_path(r"51d0f732-2fe9-40c5-b888-8143270d35bb.png"), name="button_produce.png")
 
-    ButtonShop = Image(path=sprite_path(r"fb870576-1837-4267-bc0f-e0685bf7a136.png"), name="button_shop.png")
+    ButtonShop = Image(path=sprite_path(r"cdbf1f7f-63f6-40d7-a3b6-3d64bd6f9083.png"), name="button_shop.png")
 
-    ButtonShopCapsuleToys = Image(path=sprite_path(r"62676c2c-814a-4d8b-9bb2-232c3b434287.png"), name="button_shop_capsule_toys.png")
+    ButtonShopCapsuleToys = Image(path=sprite_path(r"f79fb63f-1737-4e67-b017-0b34bc93295a.png"), name="button_shop_capsule_toys.png")
 
-    ButtonShopCapsuleToysDraw = Image(path=sprite_path(r"cf8b2ae3-f948-4204-b7da-c0801f1368f4.png"), name="button_shop_capsule_toys_draw.png")
+    ButtonShopCapsuleToysDraw = Image(path=sprite_path(r"8d595a36-a900-42ea-871f-f17f99d5d73a.png"), name="button_shop_capsule_toys_draw.png")
 
-    ButtonShopCountAdd = Image(path=sprite_path(r"ccb8054c-345d-43c9-8b2c-7b2243ad6668.png"), name="button_shop_count_add.png")
+    ButtonShopCountAdd = Image(path=sprite_path(r"e38ced13-5ab3-47ee-b10b-63b5ed4224fb.png"), name="button_shop_count_add.png")
 
-    ButtonShopCountAddDisabled = Image(path=sprite_path(r"3997a0e3-0826-4b1e-b7e9-4a36ebaaa9e8.png"), name="button_shop_count_add_disabled.png")
+    ButtonShopCountAddDisabled = Image(path=sprite_path(r"6dacc5c6-85e2-4e26-b7a4-6bda6cc3ed0e.png"), name="button_shop_count_add_disabled.png")
 
-    ButtonSupportCardUpgrade = Image(path=sprite_path(r"146c742a-0fb3-4d88-851e-ddd621533ad3.png"), name="button_support_card_upgrade.png")
+    ButtonSupportCardUpgrade = Image(path=sprite_path(r"f162875f-08d7-4a64-a7b2-2fff14497f74.png"), name="button_support_card_upgrade.png")
 
     ButtonRefreshMoneyShop = Image(path=sprite_path(r"81c97cd3-df53-44d3-bf3d-1eb4dc67b62a.png"), name="リスト更新：1回無料")
 
@@ -134,25 +134,25 @@ class Daily:
 
     BoxHomeActivelyFunds = HintBox(x1=29, y1=530, x2=109, y2=633, source_resolution=(720, 1280))
 
-    IconAssignKouchou = Image(path=sprite_path(r"77b0a64c-1e14-41d6-94af-8824982f2119.png"), name="icon_assign_kouchou.png")
+    IconAssignKouchou = Image(path=sprite_path(r"97f4f186-da9e-404c-bf1e-918f1b962fee.png"), name="icon_assign_kouchou.png")
 
-    IconAssignMiniLive = Image(path=sprite_path(r"36039a1a-52e6-428d-9866-0f0f65a7298f.png"), name="icon_assign_mini_live.png")
+    IconAssignMiniLive = Image(path=sprite_path(r"180168f7-9ead-4ce3-9cd9-b1960d649e5c.png"), name="icon_assign_mini_live.png")
 
-    IconAssignOnlineLive = Image(path=sprite_path(r"ceb4fae9-b5e5-41cf-856b-bcf753f477d9.png"), name="icon_assign_online_live.png")
+    IconAssignOnlineLive = Image(path=sprite_path(r"d3832642-3108-4947-8274-68ad8a78b690.png"), name="icon_assign_online_live.png")
 
-    IconAssignTitle = Image(path=sprite_path(r"e2a98bd2-56d1-47e9-806a-a36d06bd3f16.png"), name="icon_assign_title.png")
+    IconAssignTitle = Image(path=sprite_path(r"44b34d58-8178-416f-88bc-a3c4a5a26bac.png"), name="icon_assign_title.png")
 
-    IconMenuClub = Image(path=sprite_path(r"a921b8d5-93b7-4346-9ae4-d2e1def1ec1a.png"), name="icon_menu_club.png")
+    IconMenuClub = Image(path=sprite_path(r"c1c710cd-885b-4b2c-9752-8a2754d0f72d.png"), name="icon_menu_club.png")
 
-    IconShopAp = Image(path=sprite_path(r"04b33e1f-a341-46d4-a54b-a05f1e765c10.png"), name="icon_shop_ap.png")
+    IconShopAp = Image(path=sprite_path(r"034203b6-cadb-4b7c-af70-3e9551083457.png"), name="icon_shop_ap.png")
 
-    IconShopMoney = Image(path=sprite_path(r"a975a75e-e774-481b-8ade-9b1229bc95dd.png"), name="icon_shop_money.png")
+    IconShopMoney = Image(path=sprite_path(r"ccb670dd-7c8e-4bc9-8e73-934ce26d23a8.png"), name="icon_shop_money.png")
 
-    IconShopTitle = Image(path=sprite_path(r"f0370809-4383-4039-b8ec-f80a9216a7b3.png"), name="icon_shop_title.png")
+    IconShopTitle = Image(path=sprite_path(r"f8237a04-9f49-4796-9238-8dfab4cabcbe.png"), name="icon_shop_title.png")
 
-    IconTitleAssign = Image(path=sprite_path(r"98deb79d-e32b-4551-bc26-c4722d2b1307.png"), name="icon_title_assign.png")
+    IconTitleAssign = Image(path=sprite_path(r"bbc8ae86-9ad5-4fc7-8662-05a096ec1b84.png"), name="icon_title_assign.png")
 
-    IconTitlePass = Image(path=sprite_path(r"276239b5-e41b-4ae5-9be6-37d251292d39.png"), name="icon_title_pass.png")
+    IconTitlePass = Image(path=sprite_path(r"e707f860-027c-44ee-a7a3-b18573b539e3.png"), name="icon_title_pass.png")
 
     BoxApkUpdateDialogTitle = HintBox(x1=26, y1=905, x2=342, y2=967, source_resolution=(720, 1280))
 
@@ -202,21 +202,21 @@ class Daily:
     
     
         pass
-    TextActivityFundsMax = Image(path=sprite_path(r"03985ce5-781f-4c1b-8d49-c5f97010d5ff.png"), name="text_activity_funds_max.png")
+    TextActivityFundsMax = Image(path=sprite_path(r"0411b7d9-8f30-44c8-ad51-fde15025ab5f.png"), name="text_activity_funds_max.png")
 
-    TextAssignmentCompleted = Image(path=sprite_path(r"833ce8cb-01cd-4457-94b9-ff3f93d33f05.png"), name="text_assignment_completed.png")
+    TextAssignmentCompleted = Image(path=sprite_path(r"24b645e9-66a6-4c4b-8273-c895ba6b8324.png"), name="text_assignment_completed.png")
 
-    TextContest = Image(path=sprite_path(r"6bb37f56-bac2-4852-82b0-e9b65ce0cbe8.png"), name="text_contest.png")
+    TextContest = Image(path=sprite_path(r"c107e00b-f94f-4526-88f5-2eae03a7d7f6.png"), name="text_contest.png")
 
-    TextContestLastOngoing = Image(path=sprite_path(r"5fb96a83-7b37-435b-9d7e-9caf0bc022e4.png"), name="text_contest_last_ongoing.png")
+    TextContestLastOngoing = Image(path=sprite_path(r"1cc8c106-1830-433e-956f-7d31a01da99e.png"), name="text_contest_last_ongoing.png")
 
-    TextContestNoMemory = Image(path=sprite_path(r"fa1eea22-b329-4c1c-8446-279c542f6da0.png"), name="text_contest_no_memory.png")
+    TextContestNoMemory = Image(path=sprite_path(r"19962647-b587-488b-9ed3-1f4f7ce36406.png"), name="text_contest_no_memory.png")
 
-    TextContestOverallStats = Image(path=sprite_path(r"f60a8a24-b358-4f3a-af2c-4e4a31c5d36e.png"), name="text_contest_overall_stats.png")
+    TextContestOverallStats = Image(path=sprite_path(r"444bc913-a075-4f71-baf8-a94cbb8a8ab0.png"), name="text_contest_overall_stats.png")
 
-    TextShopRecommended = Image(path=sprite_path(r"9e5afe22-f817-45f7-b0dd-2c808adff8cb.png"), name="text_shop_recommended.png")
+    TextShopRecommended = Image(path=sprite_path(r"c38d6852-316f-4a77-9987-e15789ee8612.png"), name="text_shop_recommended.png")
 
-    TextTabShopAp = Image(path=sprite_path(r"4d0f75f5-632b-4c59-88a5-058622a4c3af.png"), name="text_tab_shop_ap.png")
+    TextTabShopAp = Image(path=sprite_path(r"c48df972-98fd-4303-99df-9374f542beda.png"), name="text_tab_shop_ap.png")
 
 
     pass
@@ -280,17 +280,17 @@ class Produce:
     
     BoxProduceOngoing = HintBox(x1=179, y1=937, x2=551, y2=1091, source_resolution=(720, 1280))
 
-    ButtonAutoSet = Image(path=sprite_path(r"8a62a66d-4b66-42d5-b004-b56eb7c45d68.png"), name="button_auto_set.png")
+    ButtonAutoSet = Image(path=sprite_path(r"28282c09-6ce2-4d65-8475-1fc6fbf54e15.png"), name="button_auto_set.png")
 
-    ButtonProduce = Image(path=sprite_path(r"7a54f094-bc75-48d3-8253-cca80a7052a2.png"), name="button_produce.png")
+    ButtonProduce = Image(path=sprite_path(r"4c4339dc-c9b2-4a3c-a80a-02512d281289.png"), name="button_produce.png")
 
-    ButtonProduceStart = Image(path=sprite_path(r"2227a4ac-a933-4165-b594-2720a26f9e44.png"), name="button_produce_start.png")
+    ButtonProduceStart = Image(path=sprite_path(r"8dfc96b9-678a-4126-914a-8b5ba920e280.png"), name="button_produce_start.png")
 
-    ButtonRegular = Image(path=sprite_path(r"9a816f64-b16e-4e8a-b4d8-d056c31c85f1.png"), name="button_regular.png")
+    ButtonRegular = Image(path=sprite_path(r"640826ef-c7cf-494c-888a-b151ef418531.png"), name="button_regular.png")
 
-    CheckboxIconNoteBoost = Image(path=sprite_path(r"80ae6f18-cc26-4b31-9202-b5a0656b23ce.png"), name="checkbox_icon_note_boost.png")
+    CheckboxIconNoteBoost = Image(path=sprite_path(r"37686733-d013-4580-b255-6db73142c0f6.png"), name="checkbox_icon_note_boost.png")
 
-    CheckboxIconSupportPtBoost = Image(path=sprite_path(r"a04c4402-e071-401a-9549-d573eabc0e59.png"), name="checkbox_icon_support_pt_boost.png")
+    CheckboxIconSupportPtBoost = Image(path=sprite_path(r"0b3b7c7d-ad01-44dd-bd25-c819eb002a31.png"), name="checkbox_icon_support_pt_boost.png")
 
     IconPIdolLevel = Image(path=sprite_path(r"30a6f399-6999-4f04-bb77-651e0214112f.png"), name="P偶像卡上的等级图标")
 
@@ -310,11 +310,11 @@ class Produce:
 
     ResumeDialogMaster = Image(path=sprite_path(r"3c8b477a-8eda-407e-9e9f-7540c8808f89.png"), name="培育再开对话框 MASTER")
 
-    RadioTextSkipCommu = Image(path=sprite_path(r"aeff3068-5f5c-4685-a328-fe367d426c46.png"), name="radio_text_skip_commu.png")
+    RadioTextSkipCommu = Image(path=sprite_path(r"2ebe4066-c47c-4284-a52d-b3f5bed523f3.png"), name="radio_text_skip_commu.png")
 
     TextAnotherIdolAvailableDialog = Image(path=sprite_path(r"cbf4ce9c-f8d8-4fb7-a197-15bb9847df04.png"), name="Another 版本偶像可用对话框标题")
 
-    ScreenshotMemoryConfirmDialog = Image(path=sprite_path(r"3746df74-fe63-442c-85d2-8a3696cb2fcd.png"), name="screenshot_memory_confirm_dialog.png")
+    ScreenshotMemoryConfirmDialog = Image(path=sprite_path(r"d61a93e8-0e24-40d8-814a-402765d057ea.png"), name="screenshot_memory_confirm_dialog.png")
 
     LogoNia = Image(path=sprite_path(r"a0bd6a5f-784d-4f0a-9d66-10f4b80c8d3e.png"), name="NIA LOGO (NEXT IDOL AUDITION)")
 
@@ -326,7 +326,7 @@ class Produce:
 
     ButtonUse = Image(path=sprite_path(r"cfc9c8e8-cbe1-49f0-9afa-ead7f9455a2e.png"), name="按钮「使う」")
 
-    ScreenshotNoEnoughAp3 = Image(path=sprite_path(r"791e885e-6e27-498f-81ff-87a40582507d.png"), name="screenshot_no_enough_ap_3.png")
+    ScreenshotNoEnoughAp3 = Image(path=sprite_path(r"649f1c6d-03f8-4e84-87a7-b3418bdb9f61.png"), name="screenshot_no_enough_ap_3.png")
 
     ButtonSkipLive = Image(path=sprite_path(r"e5e84f9e-28da-4cf4-bcba-c9145fe39b07.png"), name="培育结束跳过演出按钮")
 
@@ -376,69 +376,69 @@ class Produce:
     pass
 class InPurodyuusu:
     
-    A = Image(path=sprite_path(r"ef21cbe1-7263-4a68-ad8c-b9aac503978a.png"), name="A.png")
+    A = Image(path=sprite_path(r"88456f07-23f0-48f7-ac81-206312717095.png"), name="A.png")
 
-    AcquireBtnDisabled = Image(path=sprite_path(r"6a59aafc-4962-490e-8ab1-9ad59d22db3d.png"), name="acquire_btn_disabled.png")
+    AcquireBtnDisabled = Image(path=sprite_path(r"a5e675c9-8fc8-46f2-ae73-bc871d65daaf.png"), name="acquire_btn_disabled.png")
 
-    ButtonCancel = Image(path=sprite_path(r"382cb218-9e58-406f-9a3b-a9d990fc0fff.png"), name="button_cancel.png")
+    ButtonCancel = Image(path=sprite_path(r"974015ca-854d-43e3-a8ed-faa247d304bc.png"), name="button_cancel.png")
 
-    ButtonComplete = Image(path=sprite_path(r"54e29f7f-c951-46a2-a068-6911dfcf1966.png"), name="button_complete.png")
+    ButtonComplete = Image(path=sprite_path(r"32395105-71b0-4f98-a439-c181e82a648e.png"), name="button_complete.png")
 
-    ButtonFinalPracticeDance = Image(path=sprite_path(r"b5ecb8e2-8b1a-4240-a2c9-152ccecdacbe.png"), name="button_final_practice_dance.png")
+    ButtonFinalPracticeDance = Image(path=sprite_path(r"faeb1498-1c11-4bc7-8e85-864fd876751c.png"), name="button_final_practice_dance.png")
 
-    ButtonFinalPracticeVisual = Image(path=sprite_path(r"12f47930-f691-4a3e-8c83-e47f63fb1f2b.png"), name="button_final_practice_visual.png")
+    ButtonFinalPracticeVisual = Image(path=sprite_path(r"1989466d-c486-4e0c-acc9-ed3116e3c0b8.png"), name="button_final_practice_visual.png")
 
-    ButtonFinalPracticeVocal = Image(path=sprite_path(r"795961a5-78c5-4ac4-a250-b1879cd2f60d.png"), name="button_final_practice_vocal.png")
+    ButtonFinalPracticeVocal = Image(path=sprite_path(r"5af6d58e-52c5-47fd-8ea5-c2fa8bb67e99.png"), name="button_final_practice_vocal.png")
 
-    ButtonFollowNoIcon = Image(path=sprite_path(r"72a9238a-de6d-4665-85d4-265180d00db2.png"), name="button_follow_no_icon.png")
+    ButtonFollowNoIcon = Image(path=sprite_path(r"7465297a-497d-41fa-948d-7f04ad5fdc94.png"), name="button_follow_no_icon.png")
 
-    ButtonIconStudy = Image(path=sprite_path(r"658eb246-1469-4a86-b7a7-5e66b3102084.png"), name="button_icon_study.png")
+    ButtonIconStudy = Image(path=sprite_path(r"a43abe98-376b-4da7-ab17-b6c9e1a875fb.png"), name="button_icon_study.png")
 
-    ButtonIconStudyVisual = Image(path=sprite_path(r"30ce2e03-e9b3-4b4f-aded-51a05bfca91f.png"), name="button_icon_study_visual.png")
+    ButtonIconStudyVisual = Image(path=sprite_path(r"38526b38-7f62-466b-8702-0c657891c7fa.png"), name="button_icon_study_visual.png")
 
-    ButtonLeave = Image(path=sprite_path(r"fd354169-e32a-45be-9a1e-da0136b91dc3.png"), name="button_leave.png")
+    ButtonLeave = Image(path=sprite_path(r"4fa138a2-4f39-4023-afd4-af5be7df662b.png"), name="button_leave.png")
 
-    ButtonNextNoIcon = Image(path=sprite_path(r"ed081194-272d-461a-93a1-ec476a896753.png"), name="button_next_no_icon.png")
+    ButtonNextNoIcon = Image(path=sprite_path(r"d61df6da-4b09-4b8c-bc97-46632a80fcd9.png"), name="button_next_no_icon.png")
 
-    ButtonRetry = Image(path=sprite_path(r"47d9fac4-2caf-4479-a97a-e519ddbfb3cf.png"), name="button_retry.png")
+    ButtonRetry = Image(path=sprite_path(r"725e767e-79bb-4ce6-a448-8ebee80193b7.png"), name="button_retry.png")
 
-    ButtonTextActionOuting = Image(path=sprite_path(r"45abba60-06d7-4921-b2a2-9ce790c2b25b.png"), name="button_text_action_outing.png")
+    ButtonTextActionOuting = Image(path=sprite_path(r"f68eb4f1-b30b-43fc-8a24-11394cc759d2.png"), name="button_text_action_outing.png")
 
-    ButtonTextAllowance = Image(path=sprite_path(r"c86250ac-bde0-45bb-b696-f8b94e2d2d3b.png"), name="button_text_allowance.png")
+    ButtonTextAllowance = Image(path=sprite_path(r"64969b0b-a6ef-4342-a967-20428d5baa65.png"), name="button_text_allowance.png")
 
-    ButtonTextConsult = Image(path=sprite_path(r"6a272201-1311-41ee-b296-0a8d812d8173.png"), name="button_text_consult.png")
+    ButtonTextConsult = Image(path=sprite_path(r"cdd7bbc5-8ebd-4a5c-84ca-0e7ca7702d8f.png"), name="button_text_consult.png")
 
-    IconClearBlue = Image(path=sprite_path(r"7eff6c59-a7ed-43d5-8b67-083127e9e748.png"), name="icon_clear_blue.png")
+    IconClearBlue = Image(path=sprite_path(r"8fad2402-594e-4466-927a-1f83139d7edf.png"), name="icon_clear_blue.png")
 
-    IconTitleAllowance = Image(path=sprite_path(r"b6cda449-d5ab-4a38-9c85-c25e1b73f588.png"), name="icon_title_allowance.png")
+    IconTitleAllowance = Image(path=sprite_path(r"2e76fba4-b9db-47ce-b6a4-d0a857b3fd4b.png"), name="icon_title_allowance.png")
 
-    IconTitleStudy = Image(path=sprite_path(r"00707545-6ed3-4c3a-9c84-89cb75ac1adc.png"), name="icon_title_study.png")
+    IconTitleStudy = Image(path=sprite_path(r"cc65d34b-b220-451e-a18e-66b05b911e97.png"), name="icon_title_study.png")
 
-    LootboxSliverLock = Image(path=sprite_path(r"a4935638-882c-4d3f-af77-e5888ad0b71e.png"), name="lootbox_sliver_lock.png")
+    LootboxSliverLock = Image(path=sprite_path(r"c35208a6-261e-4a2e-aeae-aae19d8c83d6.png"), name="lootbox_sliver_lock.png")
 
-    LootBoxSkillCard = Image(path=sprite_path(r"cd8d48f2-77d2-4d0b-a81f-53a1549457e9.png"), name="loot_box_skill_card.png")
+    LootBoxSkillCard = Image(path=sprite_path(r"9d87795b-c322-49c6-a9c9-6064828a55a2.png"), name="loot_box_skill_card.png")
 
-    M = Image(path=sprite_path(r"94165d54-2c09-427f-9cb1-e23fa9b06a96.png"), name="M.png")
+    M = Image(path=sprite_path(r"e129c096-35c3-4fd8-b30c-ce92c3c9b85f.png"), name="M.png")
 
     BoxExamTop = HintBox(x1=5, y1=2, x2=712, y2=55, source_resolution=(720, 1280))
 
     BoxCardLetter = HintBox(x1=6, y1=1081, x2=715, y2=1100, source_resolution=(720, 1280))
 
-    PDrinkIcon = Image(path=sprite_path(r"fcbeb870-6853-4e2c-8a6e-54b4787e3a2e.png"), name="p_drink_icon.png")
+    PDrinkIcon = Image(path=sprite_path(r"441934e4-3659-4522-985c-0e683eb03f1c.png"), name="p_drink_icon.png")
 
-    PItemIconColorful = Image(path=sprite_path(r"08f593a9-d9eb-41ee-b2c0-010562e7ef10.png"), name="p_item_icon_colorful.png")
+    PItemIconColorful = Image(path=sprite_path(r"97f26adc-071b-4289-8243-dc20e024c7e4.png"), name="p_item_icon_colorful.png")
 
-    PSkillCardIconBlue = Image(path=sprite_path(r"5b2e7826-0e1c-4fd8-965c-6a3498c59825.png"), name="p_skill_card_icon_blue.png")
+    PSkillCardIconBlue = Image(path=sprite_path(r"5e473a8c-bf57-44d8-a711-db1f4ccc182c.png"), name="p_skill_card_icon_blue.png")
 
-    PSkillCardIconColorful = Image(path=sprite_path(r"fa72809a-d057-40a0-b771-f4d96bc1ced2.png"), name="p_skill_card_icon_colorful.png")
+    PSkillCardIconColorful = Image(path=sprite_path(r"d67de935-b5f2-4176-ab52-d0482290cb59.png"), name="p_skill_card_icon_colorful.png")
 
-    Rest = Image(path=sprite_path(r"6aa1fbb0-3880-49e1-ade3-29f627d0e38b.png"), name="rest.png")
+    Rest = Image(path=sprite_path(r"6fe17986-a29d-4198-b366-1c40637069b5.png"), name="rest.png")
 
-    RestConfirmBtn = Image(path=sprite_path(r"8b3cfcfc-fa00-4bc5-9ea4-b350f2c08cb0.png"), name="rest_confirm_btn.png")
+    RestConfirmBtn = Image(path=sprite_path(r"87b36188-2bf9-4b56-98cf-9e8df3879dbf.png"), name="rest_confirm_btn.png")
 
-    Screenshot4Cards = Image(path=sprite_path(r"35f613e8-61af-41b0-a397-44ae7566a233.png"), name="screenshot_4_cards.png")
+    Screenshot4Cards = Image(path=sprite_path(r"62b425ac-3e19-4924-8a58-c085f4d38f56.png"), name="screenshot_4_cards.png")
 
-    Screenshot5Cards = Image(path=sprite_path(r"229366ae-dbcd-4378-84a2-8a7eb1d1e084.png"), name="screenshot_5_cards.png")
+    Screenshot5Cards = Image(path=sprite_path(r"50718df3-1b0e-425f-802c-ca4abd08a4b5.png"), name="screenshot_5_cards.png")
 
     BoxWeeksUntilExam = HintBox(x1=11, y1=8, x2=237, y2=196, source_resolution=(720, 1280))
 
@@ -506,7 +506,7 @@ class InPurodyuusu:
 
     TextRecommend = Image(path=sprite_path(r"b0283997-7931-476d-a92f-d7569f6ea34c.png"), name="おすすめ")
 
-    ScreenshotSenseiTipConsult = Image(path=sprite_path(r"c89ce004-a437-4b94-9420-0d9bf2ed7e25.png"), name="screenshot_sensei_tip_consult.png")
+    ScreenshotSenseiTipConsult = Image(path=sprite_path(r"814da106-1756-4bce-9140-d2730b635e7e.png"), name="screenshot_sensei_tip_consult.png")
 
     TextSkillCardSelectGuideDialogTitle = Image(path=sprite_path(r"3f637e86-6b74-4693-9131-1fe411fc21e5.png"), name="獲得ガイド表示設定")
 
@@ -514,7 +514,7 @@ class InPurodyuusu:
 
     IconSkillCardEventBubble = Image(path=sprite_path(r"6b58d90d-2e5e-4b7f-bc01-941f2633de89.png"), name="技能卡事件气泡框图标")
 
-    ScreenshotSkillCardEnhanceDialog = Image(path=sprite_path(r"80fac9c6-e6de-4fb5-9543-77797ffcde7a.png"), name="screenshot_skill_card_enhance_dialog.png")
+    ScreenshotSkillCardEnhanceDialog = Image(path=sprite_path(r"6e3515d4-68ce-4760-948b-5fb20576fc12.png"), name="screenshot_skill_card_enhance_dialog.png")
 
     IconTitleSkillCardEnhance = Image(path=sprite_path(r"79abd239-5eed-4195-9fa8-d729daa874ca.png"), name="技能卡强化 标题 图标")
 
@@ -536,47 +536,47 @@ class InPurodyuusu:
 
     TextSelfStudyVisual = Image(path=sprite_path(r"4695f96b-c4f5-4bb6-a021-a13b6ceb2883.png"), name="文化课事件 自习 形象")
 
-    TextAsariProduceEnd = Image(path=sprite_path(r"9fb0f700-1eaf-4677-bd1f-05f9f311cdfc.png"), name="text_asari_produce_end.png")
+    TextAsariProduceEnd = Image(path=sprite_path(r"71841087-2d73-4726-943a-c784df0b0d2d.png"), name="text_asari_produce_end.png")
 
-    TextButtonExamSkipTurn = Image(path=sprite_path(r"1dd337ca-20f1-4dc6-8254-235d7ec74158.png"), name="text_button_exam_skip_turn.png")
+    TextButtonExamSkipTurn = Image(path=sprite_path(r"6a77517b-99b1-42a1-ba61-a3109151339e.png"), name="text_button_exam_skip_turn.png")
 
-    TextClearUntil = Image(path=sprite_path(r"fc7b1cdb-d0d0-4470-b5fd-218a8551dc9f.png"), name="text_clear_until.png")
+    TextClearUntil = Image(path=sprite_path(r"8af8652d-06fe-4d2c-b123-641c7fbc651d.png"), name="text_clear_until.png")
 
-    TextDance = Image(path=sprite_path(r"bdc3b84b-18a4-4abe-938d-3e6495bef7eb.png"), name="text_dance.png")
+    TextDance = Image(path=sprite_path(r"3d8ab1bb-f8a8-4b19-a565-3b06e1cfe11c.png"), name="text_dance.png")
 
-    TextFinalProduceRating = Image(path=sprite_path(r"b9e687ca-ba44-4aa1-a282-b7da6cffb2ba.png"), name="text_final_produce_rating.png")
+    TextFinalProduceRating = Image(path=sprite_path(r"c32068c9-6e52-4176-98de-fd4d252969dd.png"), name="text_final_produce_rating.png")
 
-    TextOneWeekRemaining = Image(path=sprite_path(r"359d6d34-ea55-470b-b682-6c9252953e8d.png"), name="text_one_week_remaining.png")
+    TextOneWeekRemaining = Image(path=sprite_path(r"998be65c-b835-4004-bbe0-411a4d74985c.png"), name="text_one_week_remaining.png")
 
-    TextPerfectUntil = Image(path=sprite_path(r"ae1a5e05-d53d-43aa-9f27-b9117483d19e.png"), name="text_perfect_until.png")
+    TextPerfectUntil = Image(path=sprite_path(r"59f54f2a-1efb-4d5a-b76b-b740ddf561ec.png"), name="text_perfect_until.png")
 
-    TextPleaseSelectPDrink = Image(path=sprite_path(r"1b60b852-dc93-48a1-8b73-0d728d04e057.png"), name="text_please_select_p_drink.png")
+    TextPleaseSelectPDrink = Image(path=sprite_path(r"2af71658-11c3-4c34-b604-003fb8a6a542.png"), name="text_please_select_p_drink.png")
 
-    TextPDiary = Image(path=sprite_path(r"29449202-a6cc-4080-bb87-816481ec9506.png"), name="text_p_diary.png")
+    TextPDiary = Image(path=sprite_path(r"a938bf45-e622-424f-829a-76152586f413.png"), name="text_p_diary.png")
 
-    TextPDrinkMax = Image(path=sprite_path(r"c3d5a935-6e77-4751-a0b1-b1ac3a3edf0a.png"), name="text_p_drink_max.png")
+    TextPDrinkMax = Image(path=sprite_path(r"be8a47df-79fe-48c1-b41e-77fe1a26a90b.png"), name="text_p_drink_max.png")
 
-    TextSenseiTipConsult = Image(path=sprite_path(r"71e84fb3-9474-4bbc-8543-ffba5758dcc0.png"), name="text_sensei_tip_consult.png")
+    TextSenseiTipConsult = Image(path=sprite_path(r"56c4d716-65b3-4fb8-badb-970853544c7a.png"), name="text_sensei_tip_consult.png")
 
-    TextSenseiTipDance = Image(path=sprite_path(r"7ff80aa1-94c3-417e-9fae-3c2f2b8036a8.png"), name="text_sensei_tip_dance.png")
+    TextSenseiTipDance = Image(path=sprite_path(r"e2287baf-c165-467b-8b6c-640d1f2ee376.png"), name="text_sensei_tip_dance.png")
 
-    TextSenseiTipRest = Image(path=sprite_path(r"4f2fcec7-399e-4184-b1dc-eabae92d63dd.png"), name="text_sensei_tip_rest.png")
+    TextSenseiTipRest = Image(path=sprite_path(r"288ca9e3-237f-4de6-ba06-e586a9f87d03.png"), name="text_sensei_tip_rest.png")
 
-    TextSenseiTipVisual = Image(path=sprite_path(r"2ee5d498-1370-4f09-b187-41dbe582f498.png"), name="text_sensei_tip_visual.png")
+    TextSenseiTipVisual = Image(path=sprite_path(r"87ee5cea-6fb4-4768-8767-3c422df08371.png"), name="text_sensei_tip_visual.png")
 
-    TextSenseiTipVocal = Image(path=sprite_path(r"3a41fe06-7f33-4c21-9edd-291191e3c563.png"), name="text_sensei_tip_vocal.png")
+    TextSenseiTipVocal = Image(path=sprite_path(r"d289f4e1-e92e-4263-93a4-33da4767d7a9.png"), name="text_sensei_tip_vocal.png")
 
-    TextSkipTurnDialog = Image(path=sprite_path(r"4fd7d95e-7955-4a70-ad91-67a230c647a3.png"), name="text_skip_turn_dialog.png")
+    TextSkipTurnDialog = Image(path=sprite_path(r"9ac47ce9-2594-4740-ba70-c61f97c0f992.png"), name="text_skip_turn_dialog.png")
 
-    TextVisual = Image(path=sprite_path(r"1262d83a-8f2a-4f75-b70a-385a04d35ae1.png"), name="text_visual.png")
+    TextVisual = Image(path=sprite_path(r"b6f57baa-1d05-464f-81c9-0014063d6656.png"), name="text_visual.png")
 
 
     pass
 class Kuyo:
     
-    ButtonStartGame = Image(path=sprite_path(r"3675c4aa-a208-47d1-bbcb-48bce40e6ae9.png"), name="button_start_game.png")
+    ButtonStartGame = Image(path=sprite_path(r"15552124-cc5c-4abe-b08d-123624248d77.png"), name="button_start_game.png")
 
-    ButtonTab3Speedup = Image(path=sprite_path(r"67da7040-7183-4d30-89a7-e78345f42948.png"), name="button_tab3_speedup.png")
+    ButtonTab3Speedup = Image(path=sprite_path(r"cac8bff8-569e-450f-8ac7-dad3eebf18d9.png"), name="button_tab3_speedup.png")
 
 
     pass
\ No newline at end of file
